BeaterValue

Enum BeaterValue 

pub enum BeaterValue {
Show 20 variants Bow, ChimeHammer, Coin, DrumStick, Finger, Fingernail, Fist, GuiroScraper, Hammer, Hand, JazzStick, KnittingNeedle, MetalHammer, SlideBrushOnGong, SnareStick, SpoonMallet, Superball, TriangleBeater, TriangleBeaterPlain, WireBrush,
}
Represents pictograms for beaters, mallets, and sticks that do not have different materials represented in the pictogram.

Variants



Bow



ChimeHammer



Coin



DrumStick



Finger



Fingernail



Fist



GuiroScraper



Hammer



Hand



JazzStick



KnittingNeedle



MetalHammer



SlideBrushOnGong



SnareStick



SpoonMallet



Superball



TriangleBeater



TriangleBeaterPlain



WireBrush