NumeralMode

Enum NumeralMode 

pub enum NumeralMode {
    HarmonicMinor,
    Major,
    MelodicMinor,
    Minor,
    NaturalMinor,
}
Specifies the mode similar to the mode type, but with a restricted set of values.

The different minor values are used to interpret NuermalRoot values of 6 and 7 when present in a minor key. The harmonic minor value sharpens the 7 and the melodic minor value sharpens both 6 and 7. If a minor mode is used without qualification, either in the Mode or NumeralMode elements, natural minor is used.

Variants



HarmonicMinor

Numerals are interpreted relative to a harmonic minor scale with a raised 7th degree.



Major

Numerals are interpreted relative to a major scale.



MelodicMinor

Numerals are interpreted relative to an ascending melodic minor scale with raised 6th and 7th degrees.



Minor

Numerals are interpreted relative to a natural minor scale.



NaturalMinor

Numerals are interpreted relative to a natural minor scale.