pub enum StickLocation {
Center,
CymbalBell,
CymbalEdge,
Rim,
}Expand description
Represents pictograms for the location of sticks, beaters, or mallets on cymbals, gongs, drums, and other instruments.
Variants