BeatUnitTied

Struct BeatUnitTied 

pub struct BeatUnitTied {
    pub attributes: (),
    pub content: BeatUnitTiedContents,
}
The BeatUnitTied element indicates a BeatUnit within a metronome mark that is tied to the preceding BeatUnit.

This allows two or more tied notes to be associated with a PerMinute value in a metronome mark, whereas the MetronomeTied element is restricted to metric relationship marks.

Fields

attributes: ()

Element-specific attributes

content: BeatUnitTiedContents

Element-specific content