BracketAttributes

Struct BracketAttributes 

pub struct BracketAttributes {
Show 13 fields pub line_end: LineEnd, pub type: StartStopContinue, pub color: Option<Color>, pub dash_length: Option<Tenths>, pub default_x: Option<Tenths>, pub default_y: Option<Tenths>, pub end_length: Option<Tenths>, pub id: Option<Id>, pub line_type: Option<LineType>, pub number: Option<NumberLevel>, pub relative_x: Option<Tenths>, pub relative_y: Option<Tenths>, pub space_length: Option<Tenths>,
}
Attributes pertaining to the Bracket element.

Fields

line_end: LineEnd

Specifies if there is a jog up or down (or both), an arrow, or nothing at the start or end of the bracket.

type: StartStopContinue

Indicates if this is the start, stop, or continuation of the bracket.

color: Option<Color>

Indicates the color of an element.

dash_length: Option<Tenths>

The length of dashes in a dashed line. Ignored if the corresponding line_type attribute is not dashed.

default_x: Option<Tenths>

Changes the computation of the default horizontal position. The origin is changed relative to the left-hand side of the note or the musical position within the bar. Positive x is right and negative x is left.

This attribute provides higher-resolution positioning data than the Offset element. Applications reading a MusicXML file that can understand both features should generally rely on this attribute for its greater accuracy.

default_y: Option<Tenths>

Changes the computation of the default vertical position. The origin is changed relative to the top line of the staff. Positive y is up and negative y is down.

This attribute provides higher-resolution positioning data than the placement attribute. Applications reading a MusicXML file that can understand both attributes should generally rely on this attribute for its greater accuracy.

end_length: Option<Tenths>

Specifies the length of the jog if the line_end attribute is up or down.

id: Option<Id>

Specifies an ID that is unique to the entire document.

line_type: Option<LineType>

Specifies if the line is solid, dashed, dotted, or wavy.

number: Option<NumberLevel>

Distinguishes multiple brackets when they overlap in MusicXML document order.

relative_x: Option<Tenths>

Changes the horizontal position relative to the default position, either as computed by the individual program, or as overridden by the default_x attribute. Positive x is right and negative x is left. It should be interpreted in the context of the Offset element or directive attribute if those are present.

relative_y: Option<Tenths>

Changes the vertical position relative to the default position, either as computed by the individual program, or as overridden by the default_y attribute. Positive y is up and negative y is down. It should be interpreted in the context of the placement attribute if that is present.

space_length: Option<Tenths>

The length of spaces in a dashed line. Ignored if the corresponding line_type attribute is not dashed.