InstrumentChangeContents

Struct InstrumentChangeContents 

pub struct InstrumentChangeContents {
    pub instrument_sound: Option<InstrumentSound>,
    pub solo: Option<Solo>,
    pub ensemble: Option<Ensemble>,
    pub virtual_instrument: Option<VirtualInstrument>,
}
Contents of the InstrumentChange element.

Fields

instrument_sound: Option<InstrumentSound>

The InstrumentSound element specifies the virtual instrument sound to use for a given ScoreInstrument.

solo: Option<Solo>

The Solo element specifies the solo virtual instrument sound to use for a given ScoreInstrument.

ensemble: Option<Ensemble>

The Ensemble element specifies the ensemble virtual instrument sound to use for a given ScoreInstrument.

virtual_instrument: Option<VirtualInstrument>

The VirtualInstrument element specifies the virtual instrument to use for a given ScoreInstrument.