InvertedMordentAttributes

Struct InvertedMordentAttributes 

pub struct InvertedMordentAttributes {
Show 20 fields pub accelerate: Option<YesNo>, pub approach: Option<AboveBelow>, pub beats: Option<TrillBeats>, pub color: Option<Color>, pub default_x: Option<Tenths>, pub default_y: Option<Tenths>, pub departure: Option<AboveBelow>, pub font_family: Option<FontFamily>, pub font_size: Option<FontSize>, pub font_style: Option<FontStyle>, pub font_weight: Option<FontWeight>, pub last_beat: Option<Percent>, pub long: Option<YesNo>, pub placement: Option<AboveBelow>, pub relative_x: Option<Tenths>, pub relative_y: Option<Tenths>, pub second_beat: Option<Percent>, pub start_note: Option<StartNote>, pub trill_step: Option<TrillStep>, pub two_note_turn: Option<TwoNoteTurn>,
}
Attributes pertaining to the InvertedMordent element.

Fields

accelerate: Option<YesNo>

If yes, the trill accelerates during playback. It is no if not specified.

approach: Option<AboveBelow>

Used for compound ornaments, indicating how the beginning of the ornament look relative to the main part of the mordent.

beats: Option<TrillBeats>

The number of distinct notes during playback, counting the starting note but not the two-note turn. It is 3 if not specified.

color: Option<Color>

Indicates the color of an element.

default_x: Option<Tenths>

Changes the computation of the default horizontal position. The origin is changed relative to the left-hand side of the note or the musical position within the bar. Positive x is right and negative x is left.

This attribute provides higher-resolution positioning data than the Offset element. Applications reading a MusicXML file that can understand both features should generally rely on this attribute for its greater accuracy.

default_y: Option<Tenths>

Changes the computation of the default vertical position. The origin is changed relative to the top line of the staff. Positive y is up and negative y is down.

This attribute provides higher-resolution positioning data than the placement attribute. Applications reading a MusicXML file that can understand both attributes should generally rely on this attribute for its greater accuracy.

departure: Option<AboveBelow>

Used for compound ornaments, indicating how the ending of the ornament look relative to the main part of the mordent.

font_family: Option<FontFamily>

A comma-separated list of font names.

font_size: Option<FontSize>

One of the CSS sizes or a numeric point size.

font_style: Option<FontStyle>

Normal or italic style.

font_weight: Option<FontWeight>

Normal or bold weight.

last_beat: Option<Percent>

The percentage of the way through the duration for landing on the last beat. It is 24 if not specified.

long: Option<YesNo>

Specifies if the ornament is longer than usual. The value is no if not specified.

placement: Option<AboveBelow>

Indicates whether something is above or below another element, such as a note or a notation.

relative_x: Option<Tenths>

Changes the horizontal position relative to the default position, either as computed by the individual program, or as overridden by the default_x attribute. Positive x is right and negative x is left. It should be interpreted in the context of the Offset element or directive attribute if those are present.

relative_y: Option<Tenths>

Changes the vertical position relative to the default position, either as computed by the individual program, or as overridden by the default_y attribute. Positive y is up and negative y is down. It should be interpreted in the context of the placement attribute if that is present.

second_beat: Option<Percent>

The percentage of the way through the duration for landing on the second beat. It is 12 if not specified.

start_note: Option<StartNote>

The starting note for playback, relative to the current note. It is main if not specified.

trill_step: Option<TrillStep>

The alternating note for playback, relative to the current note. It is whole if not specified.

two_note_turn: Option<TwoNoteTurn>

Specifies the two-note turn included at the end of the trill, if any. It is none if not specified.