Level

Struct Level 

pub struct Level {
    pub attributes: LevelAttributes,
    pub content: String,
}
The Level element is used to specify editorial information for different MusicXML elements.

The content contains identifying and/or descriptive text about the editorial status of the parent element.

Fields

attributes: LevelAttributes

Element-specific attributes

content: String

Element-specific content