NoteheadAttributes

Struct NoteheadAttributes 

pub struct NoteheadAttributes {
    pub color: Option<Color>,
    pub filled: Option<YesNo>,
    pub font_family: Option<FontFamily>,
    pub font_size: Option<FontSize>,
    pub font_style: Option<FontStyle>,
    pub font_weight: Option<FontWeight>,
    pub parentheses: Option<YesNo>,
    pub smufl: Option<SmuflGlyphName>,
}
Attributes pertaining to the Notehead element.

Fields

color: Option<Color>

Indicates the color of an element.

filled: Option<YesNo>

Changes the appearance of enclosed shapes from the default of hollow for half notes and longer, and filled otherwise.

font_family: Option<FontFamily>

A comma-separated list of font names.

font_size: Option<FontSize>

One of the CSS sizes or a numeric point size.

font_style: Option<FontStyle>

Normal or italic style.

font_weight: Option<FontWeight>

Normal or bold weight.

parentheses: Option<YesNo>

Specifies whether or not parentheses are put around a symbol for an editorial indication. If not specified, it is left to application defaults.

smufl: Option<SmuflGlyphName>

Indicates a particular Standard Music Font Layout (SMuFL) character using its canonical glyph name. Sometimes this is a formatting choice, and sometimes this is a refinement of the semantic meaning of an element.