PartNameDisplayContents

Struct PartNameDisplayContents 

pub struct PartNameDisplayContents {
    pub display_text: Option<DisplayText>,
    pub accidental_text: Option<AccidentalText>,
}
Contents of the PartNameDisplay element.

Fields

display_text: Option<DisplayText>

The DisplayText element specifies the text to display for the part name.

accidental_text: Option<AccidentalText>

The AccidentalText element specifies the accidental to display for the part name.