Player

Struct Player 

pub struct Player {
    pub attributes: PlayerAttributes,
    pub content: PlayerContents,
}
The Player element allows for multiple players per ScorePart for use in listening applications.

One player may play multiple instruments, while a single instrument may include multiple players in divisi sections.

Fields

attributes: PlayerAttributes

Element-specific attributes

content: PlayerContents

Element-specific content