Rights

Struct Rights 

pub struct Rights {
    pub attributes: RightsAttributes,
    pub content: String,
}
The Rights element contains copyright and other intellectual property notices.

This is similar to the Dublin Core rights element. Words, music, and derivatives can have different types, so multiple Rights elements with different type attributes are supported.

Fields

attributes: RightsAttributes

Element-specific attributes

content: String

Element-specific content