ScorePartwiseContents

Struct ScorePartwiseContents 

pub struct ScorePartwiseContents {
    pub work: Option<Work>,
    pub movement_number: Option<MovementNumber>,
    pub movement_title: Option<MovementTitle>,
    pub identification: Option<Identification>,
    pub defaults: Option<Defaults>,
    pub credit: Vec<Credit>,
    pub part_list: PartList,
    pub part: Vec<Part>,
}
Contents of the ScorePartwise element.

Fields

work: Option<Work>

The Work element specifies the work title and opus number for the score.

movement_number: Option<MovementNumber>

The MovementNumber element specifies the movement number for the score.

movement_title: Option<MovementTitle>

The MovementTitle element specifies the movement title for the score.

identification: Option<Identification>

The Identification element specifies the creators of the score.

defaults: Option<Defaults>

The Defaults element specifies the default values for the score.

credit: Vec<Credit>

The Credit element specifies the credit for the score.

part_list: PartList

The PartList element specifies the part list for the score.

part: Vec<Part>

The Part element contains the parts for the score.