TextLyric

Struct TextLyric 

pub struct TextLyric {
    pub syllabic: Option<Syllabic>,
    pub text: Text,
    pub additional: Vec<AdditionalTextLyric>,
    pub extend: Option<Extend>,
    pub end_line: Option<EndLine>,
    pub end_paragraph: Option<EndParagraph>,
    pub footnote: Option<Footnote>,
    pub level: Option<Level>,
}
The TextLyric element represents the text of a lyric.

Fields

syllabic: Option<Syllabic>

The Syllabic element represents the type of syllable for a lyric.

text: Text

The Text element represents the text of a lyric.

additional: Vec<AdditionalTextLyric>

Additional text elements that are part of the same syllable.

extend: Option<Extend>

The Extend element represents an extension of a lyric.

end_line: Option<EndLine>

The EndLine element specifies the end of a line of lyrics.

end_paragraph: Option<EndParagraph>

The EndParagraph element specifies the end of a paragraph of lyrics.

footnote: Option<Footnote>

The Footnote element specifies editorial information or lyrics content.

level: Option<Level>

The Level element specifies the editorial level of a score or part.