pub struct TupletAttributes {
pub type: StartStop,
pub bracket: Option<YesNo>,
pub default_x: Option<Tenths>,
pub default_y: Option<Tenths>,
pub id: Option<Id>,
pub line_shape: Option<LineShape>,
pub number: Option<NumberLevel>,
pub placement: Option<AboveBelow>,
pub relative_x: Option<Tenths>,
pub relative_y: Option<Tenths>,
pub show_number: Option<ShowTuplet>,
pub show_type: Option<ShowTuplet>,
}Expand description
Attributes pertaining to the Tuplet element.
Fields
type: StartStopIndicates if this is the start or stop of the tuplet.
bracket: Option<YesNo>Specifies whether or not brackets are put around a symbol for an editorial indication. If not specified, it is left to application defaults.
default_x: Option<Tenths>Changes the computation of the default horizontal position. The origin is changed relative to the left-hand side of the note or the musical position within the bar. Positive x is right and negative x is left.
This attribute provides higher-resolution positioning data than the Offset element. Applications reading a MusicXML file that can understand both features should generally rely on this attribute for its greater accuracy.
default_y: Option<Tenths>Changes the computation of the default vertical position. The origin is changed relative to the top line of the staff. Positive y is up and negative y is down.
This attribute provides higher-resolution positioning data than the placement attribute.
Applications reading a MusicXML file that can understand both attributes should generally rely on this attribute for its greater accuracy.
id: Option<Id>Specifies an ID that is unique to the entire document.
line_shape: Option<LineShape>Used to specify whether the bracket is straight or in the older curved or slurred style. It is straight if not specified.
number: Option<NumberLevel>Distinguishes nested tuplets.
placement: Option<AboveBelow>Indicates whether something is above or below another element, such as a note or a notation.
relative_x: Option<Tenths>Changes the horizontal position relative to the default position, either as computed by the individual program, or as overridden by the default_x attribute.
Positive x is right and negative x is left. It should be interpreted in the context of the Offset element or directive attribute if those are present.
relative_y: Option<Tenths>Changes the vertical position relative to the default position, either as computed by the individual program, or as overridden by the default_y attribute.
Positive y is up and negative y is down. It should be interpreted in the context of the placement attribute if that is present.
show_number: Option<ShowTuplet>Used to display either the number of actual notes, the number of both actual and normal notes, or neither. It is actual if not specified.
show_type: Option<ShowTuplet>Used to display either the actual type, both the actual and normal types, or neither. It is none if not specified.