pub struct BeatUnitTied {
pub attributes: (),
pub content: BeatUnitTiedContents,
}Expand description
The BeatUnitTied element indicates a BeatUnit within a metronome mark that is tied to the preceding BeatUnit.
This allows two or more tied notes to be associated with a PerMinute value in a metronome mark, whereas the MetronomeTied element is restricted to metric relationship marks.
Fields
attributes: ()Element-specific attributes
content: BeatUnitTiedContentsElement-specific content