SlurAttributes

Struct SlurAttributes 

pub struct SlurAttributes {
Show 19 fields pub type: StartStopContinue, pub bezier_offset: Option<Divisions>, pub bezier_offset2: Option<Divisions>, pub bezier_x: Option<Tenths>, pub bezier_x2: Option<Tenths>, pub bezier_y: Option<Tenths>, pub bezier_y2: Option<Tenths>, pub color: Option<Color>, pub dash_length: Option<Tenths>, pub default_x: Option<Tenths>, pub default_y: Option<Tenths>, pub id: Option<Id>, pub line_type: Option<LineType>, pub number: Option<NumberLevel>, pub orientation: Option<OverUnder>, pub placement: Option<AboveBelow>, pub relative_x: Option<Tenths>, pub relative_y: Option<Tenths>, pub space_length: Option<Tenths>,
}
Attributes pertaining to the Slur element.

Fields

type: StartStopContinue

Indicates if this is the start, stop, or continuation of the slur.

bezier_offset: Option<Divisions>

The horizontal position of an outgoing bezier point for slurs and ties with a start type, or of an incoming bezier point for slurs and ties with types of stop or continue. If both the bezier_x and bezier_offset attributes are present, the bezier_x attribute takes priority. This attribute is deprecated as of MusicXML 3.1.

bezier_offset2: Option<Divisions>

The horizontal position of an outgoing bezier point for slurs with a continue type. Not valid for other types. If both the bezier_x2 and bezier_offset2 attributes are present, the bezier_x2 attribute takes priority. This attribute is deprecated as of MusicXML 3.1.

bezier_x: Option<Tenths>

The horizontal position of an outgoing bezier point for slurs and ties with a start type, or of an incoming bezier point for slurs and ties with types of stop or continue.

bezier_x2: Option<Tenths>

The horizontal position of an outgoing bezier point for slurs with a continue type. Not valid for other types.

bezier_y: Option<Tenths>

The vertical position of an outgoing bezier point for slurs and ties with a start type, or of an incoming bezier point for slurs and ties with types of stop or continue.

bezier_y2: Option<Tenths>

The vertical position of an outgoing bezier point for slurs with a continue type. Not valid for other types.

color: Option<Color>

Indicates the color of an element.

dash_length: Option<Tenths>

The length of dashes in a dashed line. Ignored if the corresponding line_type attribute is not dashed.

default_x: Option<Tenths>

Changes the computation of the default horizontal position. The origin is changed relative to the left-hand side of the note or the musical position within the bar. Positive x is right and negative x is left.

This attribute provides higher-resolution positioning data than the Offset element. Applications reading a MusicXML file that can understand both features should generally rely on this attribute for its greater accuracy.

default_y: Option<Tenths>

Changes the computation of the default vertical position. The origin is changed relative to the top line of the staff. Positive y is up and negative y is down.

This attribute provides higher-resolution positioning data than the placement attribute. Applications reading a MusicXML file that can understand both attributes should generally rely on this attribute for its greater accuracy.

id: Option<Id>

Specifies an ID that is unique to the entire document.

line_type: Option<LineType>

Specifies if the line is solid, dashed, dotted, or wavy.

number: Option<NumberLevel>

Distinguishes multiple slurs when they overlap in MusicXML document order.

orientation: Option<OverUnder>

Indicates whether slurs and ties are overhand (tips down) or underhand (tips up). This is distinct from the placement attribute used by any notation type.

placement: Option<AboveBelow>

Indicates whether something is above or below another element, such as a note or a notation.

relative_x: Option<Tenths>

Changes the horizontal position relative to the default position, either as computed by the individual program, or as overridden by the default_x attribute. Positive x is right and negative x is left. It should be interpreted in the context of the Offset element or directive attribute if those are present.

relative_y: Option<Tenths>

Changes the vertical position relative to the default position, either as computed by the individual program, or as overridden by the default_y attribute. Positive y is up and negative y is down. It should be interpreted in the context of the placement attribute if that is present.

space_length: Option<Tenths>

The length of spaces in a dashed line. Ignored if the corresponding line_type attribute is not dashed.